
import 'dart:async';
import 'dart:io';
import 'dart:convert';
import 'dart:typed_data';
import 'package:flutter/services.dart';

var kChannel = const MethodChannel('nessmediametadataretriever');

class NessMetadataRetriever {
  static Future<NessMetadata> fromFile(File file) async {
    return NessMetadata.fromMap(await kChannel
        .invokeMethod('NessMetadataRetriever', {'filePath': file.path}));
  }
}
class NessMetadata {
  final String? title;
  final String? artist;
  final String? album;
  final String? albumArtist;
  final Duration? duration;
  final String? path;
  final Uint8List? albumArt;

  const NessMetadata(
      {this.title,
        this.artist,
        this.album,
        this.albumArtist,
        this.duration,
        this.path,
        this.albumArt});

  static fromMap(dynamic map) => NessMetadata(
    title: map['metadata']['title'],
    artist: map['metadata']['artist'],
    album: map['metadata']['album'],
    albumArtist: map['metadata']['albumArtist'],
    duration: Duration(milliseconds: map['metadata']['duration']),
    path: map['metadata']['path'],
    albumArt: map['albumArt'],
  );

  Map<String, dynamic> toMap() => {
    'title': title,
    'artist': artist,
    'album': album,
    'albumArtist': albumArtist,
    'duration': duration,
    'path': path,
    'albumArt': albumArt,
  };

  @override
  String toString() => JsonEncoder.withIndent('    ').convert(toMap());
}

int? parse(String? string) {
  if (string == null) return null;
  try {
    try {
      return int.parse(string);
    } catch (exception) {
      return int.parse(string.split('/').first);
    }
  } catch (exception) {}
  return null;
}